@@ -111,7 +111,7 @@ def PlotHydroPhase(PlanetList, Params):
                 ax.legend(handles, lbls)
 
         plt.tight_layout()
-        fig.savefig(Params.FigureFiles.vphase, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(Params.FigureFiles.vphase, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Hydrosphere phase diagram saved to file: {Params.FigureFiles.vphase}')
         plt.close()
     
@@ -196,15 +196,15 @@ def PlotPvThydro(PlanetList, Params):
             GS[np.where(phases == ice)] = GSice[np.where(phases == ice)]
             sig[np.where(phases == ice)] = Planet.Ocean.sigmaIce_Sm[iceStr]
 
-        # Geotherm curve
-        Pgeo = Planet.P_MPa[:Planet.Steps.nHydro] * FigLbl.PmultHydro
-        Tgeo = Planet.T_K[:Planet.Steps.nHydro]
+        # Highlight places where alpha is negative with opposite side of diverging colormap, 0 pegged to middle
+        minAlpha = np.minimum(0, np.min(alpha))
+        alphaCmap = Color.ComboPvThydroCmap(minAlpha, np.max(alpha))
 
         # Plot colormaps of hydrosphere data
         Pscaled = P_MPa * FigLbl.PmultHydro
         rhoPlot =   axes[0,0].pcolormesh(T_K, Pscaled, rho, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
         CpPlot =    axes[1,0].pcolormesh(T_K, Pscaled, Cp, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
-        alphaPlot = axes[1,1].pcolormesh(T_K, Pscaled, alpha, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
+        alphaPlot = axes[1,1].pcolormesh(T_K, Pscaled, alpha, cmap=alphaCmap, rasterized=FigMisc.PT_RASTER)
         sigPlot =   axes[0,1].pcolormesh(T_K, Pscaled, sig, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
         VPplot =    axes[0,2].pcolormesh(T_K, Pscaled, VP, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
         VSplot =    axes[1,2].pcolormesh(T_K, Pscaled, VS, cmap=Color.PvThydroCmap, rasterized=FigMisc.PT_RASTER)
@@ -241,7 +241,7 @@ def PlotPvThydro(PlanetList, Params):
 
 
         plt.tight_layout()
-        fig.savefig(Params.FigureFiles.vpvtHydro, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(Params.FigureFiles.vpvtHydro, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Hydrosphere PT properties plot saved to file: {Params.FigureFiles.vpvtHydro}')
         plt.close()
 
@@ -391,7 +391,7 @@ def PlotPvTPerpleX(PlanetList, Params):
                  color=Color.geothermInner) for ax in axf]
 
         plt.tight_layout()
-        fig.savefig(Params.FigureFiles.vpvtPerpleX, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(Params.FigureFiles.vpvtPerpleX, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Silicate/core PT properties plot saved to file: {Params.FigureFiles.vpvtPerpleX}')
         plt.close()
 
