@@ -4,7 +4,7 @@ import spiceypy as spice
 from PlanetProfile.Utilities.defineStructs import ColorStruct, StyleStruct, \
     FigLblStruct, FigSizeStruct, FigMiscStruct
 
-configPlotsVersion = 12  # Integer number for config file version. Increment when new settings are added to the default config file.
+configPlotsVersion = 13  # Integer number for config file version. Increment when new settings are added to the default config file.
 
 def plotAssign():
     Color = ColorStruct()
@@ -67,6 +67,9 @@ def plotAssign():
     Color.PvThydroCmapName = 'Blues'
     Color.PvThydroHi = 1.0
     Color.PvThydroLo = 0.2
+    Color.negPvThydroCmapName = 'Reds'
+    Color.negPvThydroHi = 0.5
+    Color.negPvThydroLo = 0.0
 
     # PvTPerpleX properties colormaps
     Color.PvTsilCmapName = 'copper'
@@ -244,9 +247,11 @@ def plotAssign():
     FigMisc.FORCE_0_EDGES = True  # Sets the edge of plots with 0 radius, depth, pressure, etc. to be the edge of the axes, instead of including white space which is the default.
 
     # Hydrosphere plots
+    FigMisc.LOG_SIG = True  # Whether to print conductivity plot on a log scale
     FigMisc.SCALE_HYDRO_LW = True  # Whether to adjust thickness of lines on hydrosphere plot according to relative salinity
     FigMisc.MANUAL_HYDRO_COLORS = True  # Whether to set color of lines in hydrosphere according to melting temperature
     FigMisc.RELATIVE_Tb_K = True  # Whether to set colormap of lines based on relative comparison (or fixed settings in ColorStruct)
+    FigMisc.lowSigCutoff_Sm = 1e-3  # Cutoff conductivity below which profiles will be excluded. Setting to None includes all profiles
     FigMisc.TminHydro = 200  # Minimum temperature to display on hydrosphere plots
     FigMisc.PHASE_LABELS = True  # Whether to print phase labels on density plots
     FigLbl.TS_hydroLabels = 18  # Font size for hydrosphere phase labels in pt
@@ -313,7 +318,8 @@ def plotAssign():
     FigMisc.NORMALIZED_SALINITIES = False  # Whether to normalize salinities to absolute concentrations relative to the saturation limit for each salt
     FigMisc.NORMALIZED_TEMPERATURES = False  # Whether to normalize ocean mean temperatures to specified maxima and minima for the colormap
     # Inductograms
-    FigMisc.PLOT_V2021 = False  # Mark the selected ocean/conductivity combos used in Vance et al. 2021
+    FigMisc.MARK_INDUCT_BOUNDS = True  # Whether to draw a border around the models on sigma/D plot when combined
+    FigMisc.PLOT_V2021 = False  # Whether to mark the selected ocean/conductivity combos used in Vance et al. 2021
     # Excitation spectra
     FigMisc.MAG_SPECTRA_PERIODS = True  # Plot against periods for magnetic spectra plots (or frequencies)
     FigMisc.MARK_TEXC = True  # Add lines marking the main excitation periods/frequencies on Ae1 plot
@@ -353,9 +359,13 @@ def plotAssign():
     # Colorbar settings
     FigMisc.cbarTitleSize = 'small'  # Font size specifier for colorbar titles
     FigMisc.cbarFmt = '%.1f'  # Format string to use for colorbar units
+    FigMisc.cbarSize = '5%'  # Description of the size of colorbar to use with make_axes_locatable (secondary colorbars in phase space plots)
     FigMisc.cbarSpace = 0.5  # Amount of whitespace in inches to use for colorbars
     FigMisc.extraPad = FigMisc.cbarSpace * 0.8  # Amount of extra padding to apply to secondary colorbars
     FigMisc.nCbarPts = 80  # Number of points to use for drawing colorbar gradient
     FigMisc.SetFontSizes()  # Assign sizes for fonts
 
+    # Assign metadata for correct output format combination
+    FigLbl.SetMeta(FigMisc.figFormat)
+
     return Color, Style, FigLbl, FigSize, FigMisc
