@@ -7,6 +7,7 @@ import numpy as np
 import spiceypy as spice
 from PlanetProfile.GetConfig import Params
 from PlanetProfile.TrajecAnalysis.SpiceFuncs import LoadKernels, BodyDist_km, BiTrajec, spiceSCname
+from MoonMag.field_xyz import eval_Bi_Schmidt
 
 # Assign logger
 log = logging.getLogger('PlanetProfile')
@@ -41,7 +42,7 @@ class FlybyCAStruct:
                 'Jupiter': {'J': '1979-07-09T22:29:01.964'},
                 'Saturn':  {'S': '1981-08-26T03:24:04.760'},
                 'Uranus':  {'U': '1986-01-24T17:58:51.346'},
-                'Neptune': {'N': '1989-08-25T03:55:40.075'}
+                'Neptune': {'N': '1989-08-25T03:55:40.076'}
             }
         elif self.scName == 'Galileo':
             self.tCA_UTC = {
@@ -160,4 +161,95 @@ def GetActualCA(spiceSCname, t_UTC, bodyname, range_min=5, res_s=0.001):
 FlybyCA = {scName: FlybyCAStruct(scName) for scName in scNames}
 [FlybyCA[sc].GetrCA() for sc in scNames]
 
+def Ws(et, planet=None, epoch='J2000'):
+    W_deg = {}
+    if epoch == 'J1950':
+        J1950 = mp.mpf(spice.str2et('1950 Jan 01 00:00:00.000 TDB'))
+        d = (et - J1950)/86400
+        N = 357.85 + 52.316*d/36525
+        W_deg['J'] = np.round(float(mp.fmod( 80.6 + 870.536*d, 360)),3)
+        W_deg['S'] = np.round(float(mp.fmod(360.0 + 810.7939024*d, 360)),3)
+        W_deg['U'] = np.round(float(mp.fmod(360.0 - 501.1600928*d, 360)),3)
+        W_deg['N'] = np.round(float(mp.fmod(360.0 + 536.3128492*d - 0.48*mp.sin(mp.radians(N)), 360)),3)
+    else:
+        d = et/86400
+        N = 357.85 + 52.316*d/36525
+        W_deg['J'] = np.round(float(mp.fmod(284.95  + 870.5360000*d, 360)),3)
+        W_deg['S'] = np.round(float(mp.fmod( 38.90  + 810.7939024*d, 360)),3)
+        W_deg['U'] = np.round(float(mp.fmod(203.81  - 501.1600928*d, 360)),3)
+        W_deg['N'] = np.round(float(mp.fmod(253.18  + 536.3128492*d - 0.48*mp.sin(mp.radians(N)), 360)),3)
+    if planet is None or planet.lower() == 'all':
+        return W_deg
+    else:
+        return W_deg[planet[0].upper()]
+    
+def Bxyz2Bsph(Bx, By, Bz, theta, phi):
+    # Convert vector components aligned to cartesian axes
+    # into vector components aligned to spherical coordinates.
+    # Source: Arfken, Weber, Harris, Mathematical Methods for Physicists,
+    # 7th ed, pg. 199 for the unit vectors.
+    Br   =  np.sin(theta) * np.cos(phi) * Bx + np.sin(theta) * np.sin(phi) * By + np.cos(theta) * Bz
+    Bth  =  np.cos(theta) * np.cos(phi) * Bx + np.cos(theta) * np.sin(phi) * By - np.sin(theta) * Bz
+    Bphi =                 -np.sin(phi) * Bx +                 np.cos(phi) * By
+    return Br, Bth, Bphi
 
+import mpmath as mp
+J1950_0 = mp.mpf(86400*(2433282.423357 - 2451545))
+J1950 = mp.mpf(spice.str2et('1950 Jan 01 00:00:00.000 TDB'))
+J1957 = mp.mpf(spice.str2et('1957-01-01T00:00:00.000'))
+J1965 = mp.mpf(spice.str2et('1965 Jan 01 00:00:00.000 TDB'))
+J1980 = mp.mpf(spice.str2et('1980-01-01T00:00:00.000'))
+J2000 = mp.mpf(0)
+etULS = mp.mpf(spice.str2et('1986-01-24T18:00:00.000'))
+etNLS = mp.mpf(spice.str2et('1989-08-25T03:56:00.000'))
+eqS1980 = np.round(float(mp.fmod(90 - 40.589 * J1980/86400/36525, 360)),2)
+W1950_0, W1950, W1957, W1965, WULS, WNLS, W1980, W2000 \
+    = (Ws(J1950_0), Ws(J1950), Ws(J1957), Ws(J1965), Ws(etULS), Ws(etNLS), Ws(J1980), Ws(J2000))
+
+import os
+parentName = 'Neptune'
+t, r, lat, lon, BrSC, BthSC, BphiSC = np.loadtxt(os.path.join('SpacecraftMAGdata', 'Voyager 2', f'vg2_{parentName}_12s_sph.tab'),
+                                                unpack=True, dtype='U23,f,f,f,f,f,f')
+ets = spice.str2et(t)
+theta = np.radians(90 - lat)
+phi = np.radians(360 - lon)
+x = r * np.sin(theta) * np.cos(phi)
+y = r * np.sin(theta) * np.sin(phi)
+z = r * np.cos(theta)
+gnm = 1e5 * np.loadtxt('/Users/mjstyczi/PlanetMag/modelCoeffs/coeffsNeptuneO8g.csv', skiprows=2, delimiter=',')
+hnm = 1e5 * np.loadtxt('/Users/mjstyczi/PlanetMag/modelCoeffs/coeffsNeptuneO8h.csv', skiprows=2, delimiter=',')
+
+Bx, By, Bz = (np.zeros_like(BrSC) for _ in range(3))
+for n in range(1,3+1):
+    for m in range(n+1):
+        dBx, dBy, dBz = eval_Bi_Schmidt(n, m, gnm[n-1,m], hnm[n-1,m], x, y, z, r)
+        Bx = Bx + dBx
+        By = By + dBy
+        Bz = Bz + dBz
+
+BrN3, BthN3, BphiN3 = Bxyz2Bsph(Bx, By, Bz, theta, phi)
+with open('/Users/mjstyczi/PlanetMag/MAG/Voyager 2/VG2_comp.tab', 'w') as f:
+    f.write(' '.join(['UTC event time'.ljust(24),
+                      'R (R_N)'.ljust(24),
+                      'theta (rad)'.ljust(24),
+                      'phi (rad)'.ljust(24),
+                      'BrSC (nT)'.ljust(24),
+                      'BthSC (nT)'.ljust(24),
+                      'BphiSC (nT)'.ljust(24),
+                      'BrNmax=3 (nT)'.ljust(24),
+                      'BthNmax=3 (nT)'.ljust(24),
+                      'BphiNmax=3 (nT)']) + '\n')
+    for i in range(np.size(BrN3)):
+        f.write(' '.join([
+            t[i],
+            f'{r[i]:24.17e}',
+            f'{theta[i]:24.17e}',
+            f'{phi[i]:24.17e}',
+            f'{BrSC[i]:24.17e}',
+            f'{BthSC[i]:24.17e}',
+            f'{BphiSC[i]:24.17e}',
+            f'{BrN3[i]:24.17e}',
+            f'{BthN3[i]:24.17e}',
+            f'{BphiN3[i]:24.17e}\n '
+        ]))
+a=0
